@@ -16,11 +16,11 @@ Struct::Path::PerlStyle - Perl-style syntax frontend for L<Struct::Path|Struct::
 
 =head1 VERSION
 
-Version 0.32
+Version 0.33
 
 =cut
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
 =head1 SYNOPSIS
 
@@ -33,15 +33,9 @@ our $VERSION = '0.32';
 
 Nothing is exported by default.
 
-=head1 SUBROUTINES
+=head1 PATH SYNTAX
 
-=head2 ps_parse
-
-Parse perl-style string to L<Struct::Path|Struct::Path> path
-
-    $struct_path = ps_parse($string);
-
-Path syntax examples:
+Examples:
 
     "{a}{b}"              # means b's value
     "{a}{}"               # all values from a's subhash; same for arrays (using empty square brackets)
@@ -53,6 +47,15 @@ Path syntax examples:
     "{a}{b}[9..0]"        # descending ranges allowed (perl doesn't)
     "{a}{b}<{c}"          # step back (perl incompatible)
 
+
+=head1 SUBROUTINES
+
+=head2 ps_parse
+
+Parse perl-style string to L<Struct::Path|Struct::Path> path
+
+    $struct_path = ps_parse($string);
+
 =cut
 
 our $OPERATORS = {
